@@ -15,43 +15,43 @@
 /*!
  * @praise Vishnu
  */
-egykl::egykl(QWidget *felvnl,jelzpn *megkap) : QTreeWidget(felvnl)
+egykl::egykl(QWidget *felvnl,jelzpn *nybnvn) : QTreeWidget(felvnl)
 <%
 	setDragEnabled(1);
 	setAcceptDrops(1);
 	setDropIndicatorShown(1);
 	setDragDropMode(QAbstractItemView::InternalMove);
 	header()->hide();
-	kidlgz=megkap;
+	kidlgz=nybnvn;
 	connect(this,SIGNAL(itemSelectionChanged()),
 		this,SLOT(eler()));
 	kitzjl=0;
 %>
 
-void egykl::kelt(const zagv&tqrost)
+void egykl::kivalt(const zagv&tqrost)
 <%
-	int kivalt=tqrost[3].toInt();
-	switch(kivalt)
+	int fldlgz=tqrost[3].toInt();
+	switch(fldlgz)
 	<%
 		case ossz:
 			<%
 				QTreeWidgetItem *prl=new QTreeWidgetItem(this);
-				int bprl=tqrost[2].toInt();
-				prl->setText(0,kidlgz->kket.value(bprl)->mzgat);
+				int irnyjl=tqrost[2].toInt();
+				prl->setText(0,kidlgz->kket.value(irnyjl)->mzgat);
 				prl->setData(0,Qt::UserRole,tqrost[2]);
 				addTopLevelItem(prl);
-				kket[bprl]=prl;
+				kket[irnyjl]=prl;
 			%>
 			break;
 		case krszt:
 			<%
 				if(tqrost[jelzpo].toInt()==nztegns) return;
 
-				int bprl=tqrost[2].toInt();
-				QTreeWidgetItem *prl=kket.value(bprl);
-				prl->setText(0,kidlgz->kket.value(bprl)->mzgat);
+				int irnyjl=tqrost[2].toInt();
+				QTreeWidgetItem *prl=kket.value(irnyjl);
+				prl->setText(0,kidlgz->kket.value(irnyjl)->mzgat);
 
-				prmza *klsirz=kidlgz->kket.value(bprl);
+				prmza *klsirz=kidlgz->kket.value(irnyjl);
 				prl->setBackgroundColor(0,klsirz->akdaly().kitzjl);
 			%>
 			break;
@@ -65,36 +65,36 @@ void egykl::kelt(const zagv&tqrost)
 					return;
 				%>
 
-				int bprl=tqrost[2].toInt();
+				int irnyjl=tqrost[2].toInt();
 
-				QList<QTreeWidgetItem *> fldlgz=selectedItems();
-				if(fldlgz.size()>1)
+				QList<QTreeWidgetItem *> bprl=selectedItems();
+				if(bprl.size()>1)
 				<%
-					foreach(QTreeWidgetItem* prl,fldlgz)
+					foreach(QTreeWidgetItem* prl,bprl)
 					<%
 						prl->setSelected(0);
 					%>
 				%>
-				else if(fldlgz.size()==1)
+				else if(bprl.size()==1)
 				<%
-					QTreeWidgetItem *prl=fldlgz.at(0);
+					QTreeWidgetItem *prl=bprl.at(0);
 					int jlzpnt=prl->data(0,Qt::UserRole).toInt();
-					if(jlzpnt!=bprl)
+					if(jlzpnt!=irnyjl)
 					<%
 						prl->setSelected(0);
-						if(bprl>0)
+						if(irnyjl>0)
 						<%
-							kket.value(bprl)->setSelected(1);
-							kket.value(bprl)->setExpanded(1);
+							kket.value(irnyjl)->setSelected(1);
+							kket.value(irnyjl)->setExpanded(1);
 						%>
 					%>
 				%>
 				else
 				<%
-					if(bprl>0)
+					if(irnyjl>0)
 					<%
-						kket.value(bprl)->setSelected(1);
-						kket.value(bprl)->setExpanded(1);
+						kket.value(irnyjl)->setSelected(1);
+						kket.value(irnyjl)->setExpanded(1);
 					%>
 				%>
 				kitzjl=0;
@@ -102,37 +102,37 @@ void egykl::kelt(const zagv&tqrost)
 			break;
 		case lnc:
 			<%
-				QTreeWidgetItem *bprl=kket.value(tqrost[2].toInt());
-				QTreeWidgetItem *irnyjl=kket.value(tqrost[0].toInt());
-				QTreeWidgetItem *mrtdt=takeTopLevelItem(indexOfTopLevelItem(bprl));
-				irnyjl->insertChild(irnyjl->childCount(),bprl);
-				irnyjl->setExpanded(1);
+				QTreeWidgetItem *jlzpnt=kket.value(tqrost[2].toInt());
+				QTreeWidgetItem *bprl=kket.value(tqrost[0].toInt());
+				QTreeWidgetItem *mrtdt=takeTopLevelItem(indexOfTopLevelItem(jlzpnt));
+				bprl->insertChild(bprl->childCount(),jlzpnt);
+				bprl->setExpanded(1);
 
 				prmza *klsirz=kidlgz->kket.value(tqrost[2].toInt());
-				bprl->setBackgroundColor(0,klsirz->akdaly().kitzjl);
+				jlzpnt->setBackgroundColor(0,klsirz->akdaly().kitzjl);
 			%>
 			break;
 		case nlnc:
 			<%
-				QTreeWidgetItem *bprl=kket.value(tqrost[4].toInt());
-				QTreeWidgetItem *irnyjl=kket.value(tqrost[5].toInt());
-				if(bprl->parent()==irnyjl)
+				QTreeWidgetItem *jlzpnt=kket.value(tqrost[4].toInt());
+				QTreeWidgetItem *bprl=kket.value(tqrost[5].toInt());
+				if(jlzpnt->parent()==bprl)
 				<%
-					irnyjl->takeChild(irnyjl->indexOfChild(bprl));
-					irnyjl->setExpanded(1);
-					addTopLevelItem(bprl);
+					bprl->takeChild(bprl->indexOfChild(jlzpnt));
+					bprl->setExpanded(1);
+					addTopLevelItem(jlzpnt);
 
 					prmza *klsirz=kidlgz->kket.value(tqrost[4].toInt());
-					bprl->setBackgroundColor(0,klsirz->akdaly().kitzjl);
+					jlzpnt->setBackgroundColor(0,klsirz->akdaly().kitzjl);
 				%>
-				else if(irnyjl->parent()==bprl)
+				else if(bprl->parent()==jlzpnt)
 				<%
-					bprl->takeChild(bprl->indexOfChild(irnyjl));
-					bprl->setExpanded(1);
-					addTopLevelItem(irnyjl);
+					jlzpnt->takeChild(jlzpnt->indexOfChild(bprl));
+					jlzpnt->setExpanded(1);
+					addTopLevelItem(bprl);
 
 					prmza *klsirz=kidlgz->kket.value(tqrost[5].toInt());
-					irnyjl->setBackgroundColor(0,klsirz->akdaly().kitzjl);
+					bprl->setBackgroundColor(0,klsirz->akdaly().kitzjl);
 				%>
 				else
 				<%
@@ -143,10 +143,10 @@ void egykl::kelt(const zagv&tqrost)
 			<%
 				QTreeWidgetItem *prl=kket.value(tqrost[2].toInt());
 
-				QTreeWidgetItem *fldlgz=0;
-				while((fldlgz=prl->takeChild(0))!=0)
+				QTreeWidgetItem *jlzpnt=0;
+				while((jlzpnt=prl->takeChild(0))!=0)
 				<%
-					addTopLevelItem(fldlgz);
+					addTopLevelItem(jlzpnt);
 				%>
 				if(prl->parent())
 					prl->parent()->takeChild(prl->parent()->indexOfChild(prl));
@@ -159,21 +159,21 @@ void egykl::kelt(const zagv&tqrost)
 			<%
 				if(tqrost[jelzpo].toInt()==nztegns) return;
 
-				int bprl=tqrost[2].toInt();
+				int irnyjl=tqrost[2].toInt();
 
-				QTreeWidgetItem *prl=kket.value(bprl);
+				QTreeWidgetItem *prl=kket.value(irnyjl);
 				int jlzpnt=0;
 				for(int i=0; i<kidlgz->eler.size(); i++)
 				<%
 					QPoint mrtdt=kidlgz->eler.at(i);
-					if(mrtdt.x()==bprl)
+					if(mrtdt.x()==irnyjl)
 					<%
-						QTreeWidgetItem *irnyjl=kket.value(mrtdt.y());
-						int alafng=prl->indexOfChild(irnyjl);
-						if(alafng!=jlzpnt)
+						QTreeWidgetItem *bprl=kket.value(mrtdt.y());
+						int rgsztg=prl->indexOfChild(bprl);
+						if(rgsztg!=jlzpnt)
 						<%
-							prl->takeChild(alafng);
-							prl->insertChild(jlzpnt,irnyjl);
+							prl->takeChild(rgsztg);
+							prl->insertChild(jlzpnt,bprl);
 						%>
 						jlzpnt++;
 					%>
@@ -186,11 +186,11 @@ void egykl::kelt(const zagv&tqrost)
 %>
 
 #if 0
-void egykl::doubleClickHandler(QTreeWidgetItem* irnyjl,int)
+void egykl::doubleClickHandler(QTreeWidgetItem* megkap,int)
 <%
-	if(irnyjl)
+	if(megkap)
 	<%
-		QTreeWidgetItem *prl=new QTreeWidgetItem(irnyjl);
+		QTreeWidgetItem *prl=new QTreeWidgetItem(megkap);
 		prl->setText(0,"hello");
 	%>
 	else
@@ -234,17 +234,17 @@ void egykl::vnl(const QString & lnmtat)
 
 bool egykl::prmz(QTreeWidgetItem * eljar,const QString & lnmtat)
 <%
-	bool jlzpnt =(eljar->text(0).indexOf(lnmtat,0,Qt::CaseInsensitive) >= 0);
+	bool irnyjl =(eljar->text(0).indexOf(lnmtat,0,Qt::CaseInsensitive) >= 0);
 	int adelk=eljar->childCount();
 
 	for(int i=0; i<adelk; ++i)
 	<%
-		QTreeWidgetItem *fldlgz=eljar->child(i);
-		jlzpnt=prmz(fldlgz,lnmtat) or jlzpnt;
+		QTreeWidgetItem *jlzpnt=eljar->child(i);
+		irnyjl=prmz(jlzpnt,lnmtat) or irnyjl;
 	%>
 
-	eljar->setHidden(!jlzpnt);
-	return jlzpnt;
+	eljar->setHidden(!irnyjl);
+	return irnyjl;
 %>
 
 void egykl::dropEvent(QDropEvent *mgmnkl)
@@ -253,17 +253,17 @@ void egykl::dropEvent(QDropEvent *mgmnkl)
 	<%
 		mgmnkl->accept();
 		QTreeWidgetItem *prl=itemAt(mgmnkl->pos());
-		QTreeWidgetItem *fldlgz=selectedItems().at(0);
+		QTreeWidgetItem *jlzpnt=selectedItems().at(0);
 
-		if(fldlgz)
+		if(jlzpnt)
 		<%
-			int bprl=fldlgz->data(0,Qt::UserRole).toInt();
+			int irnyjl=jlzpnt->data(0,Qt::UserRole).toInt();
 			if(dropIndicatorPosition()==QAbstractItemView::OnItem)
 			<%
-				if(kidlgz->prmz(bprl)) kidlgz->fhlhjt(bprl,kidlgz->prmz(bprl));
+				if(kidlgz->prmz(irnyjl)) kidlgz->fhlhjt(irnyjl,kidlgz->prmz(irnyjl));
 				if(prl!=0)
 				<%
-					kidlgz->csals(prl->data(0,Qt::UserRole).toInt(),bprl);
+					kidlgz->csals(prl->data(0,Qt::UserRole).toInt(),irnyjl);
 				%>
 			%>
 			else if(prl!=0)
@@ -271,10 +271,10 @@ void egykl::dropEvent(QDropEvent *mgmnkl)
 				int j=prl->data(0,Qt::UserRole).toInt();
 				int k=kidlgz->prmz(j);
 
-				if(kidlgz->prmz(bprl)!=k);
+				if(kidlgz->prmz(irnyjl)!=k);
 				<%
-					if(kidlgz->prmz(bprl)) kidlgz->fhlhjt(bprl,kidlgz->prmz(bprl));
-					kidlgz->csals(k,bprl);
+					if(kidlgz->prmz(irnyjl)) kidlgz->fhlhjt(irnyjl,kidlgz->prmz(irnyjl));
+					kidlgz->csals(k,irnyjl);
 				%>
 
 				int z=1;
@@ -291,14 +291,14 @@ void egykl::dropEvent(QDropEvent *mgmnkl)
 					<%
 						if(mrtdt.y()==j)
 						<%
-							kidlgz->ceco(k,bprl,l+z);
+							kidlgz->ceco(k,irnyjl,l+z);
 							break;
 						%>
 						l++;
 					%>
 				%>
 			%>
-			kidlgz->korrkt(bprl);
+			kidlgz->korrkt(irnyjl);
 		%>
 	%>
 	stopAutoScroll();
