@@ -12,14 +12,14 @@ class egyklh : public QStackedWidget
 <%
 	Q_OBJECT
 	public:
-		egyklh(QWidget *felvnl, jelzpn *megkap);
+		egyklh(QWidget *felvnl, jelzpn *nybnvn);
 		jelzpn *kidlgz;
 
 		QLabel *jlzpnt;
 		QWebView *irnyjl;
 
 	public slots:
-		void kelt(const zagv&);
+		void kivalt(const zagv&);
 %>;
 
 #endif
