@@ -26,26 +26,26 @@
 /*!
  * @praise Vishnu
  */
-oszk::oszk(QWidget *felvnl,jelzpn *megkap) : QWidget(felvnl)
+oszk::oszk(QWidget *felvnl,jelzpn *nybnvn) : QWidget(felvnl)
 <%
 	setCursor(Qt::PointingHandCursor);
-	kidlgz=megkap;
+	kidlgz=nybnvn;
 	jlzpnt=0;
 
 	setContextMenuPolicy(Qt::CustomContextMenu);
 	connect(this,SIGNAL(customContextMenuRequested(const QPoint&)),this,SLOT(bprl(const QPoint&)));
 
-	prmz=new QAction(ts_245,this);
+	prmz=new QAction(ts_246,this);
         connect(prmz,SIGNAL(triggered()),this,SLOT(kket()));
 	addAction(prmz);
 
-	kitzjl=new QAction(ts_246,this);
-        connect(kitzjl,SIGNAL(triggered()),this,SLOT(mgmnkl()));
+	kitzjl=new QAction(ts_247,this);
+        connect(kitzjl,SIGNAL(triggered()),this,SLOT(vnl()));
 	addAction(kitzjl);
 
-	alkt=new QMenu(this);
-        alkt->addAction(prmz);
-        alkt->addAction(kitzjl);
+	elodez=new QMenu(this);
+        elodez->addAction(prmz);
+        elodez->addAction(kitzjl);
 
 	setAcceptDrops(1);
 
@@ -62,25 +62,25 @@ void oszk::paintEvent(QPaintEvent*)
 	QPainter p(this);
 	QRect r=rect();
 	if(!r.width() or !r.height()) return;
-	if(prl.isNull())
+	if(eler.isNull())
 	<%
 		if(jlzpnt)
 		<%
-			p.drawText(r,Qt::AlignCenter,ts_247);
+			p.drawText(r,Qt::AlignCenter,ts_248);
 		%>
 		else
 		<%
-			p.drawText(r,Qt::AlignCenter,ts_248);
+			p.drawText(r,Qt::AlignCenter,ts_249);
 		%>
 		return;
 	%>
 
-	QRect rp=prl.rect();
+	QRect rp=eler.rect();
 
 	if(rp.width() < r.width() and rp.height() < r.height())
 	<%
 		QRect ru((r.width() - rp.width())/2,(r.height() - rp.height())/2,rp.width(),rp.height());
-		p.drawPixmap(ru,prl);
+		p.drawPixmap(ru,eler);
 	%>
 	else if(rp.width() * r.height() / rp.height() - r.width() > 0)
 	<%
@@ -88,7 +88,7 @@ void oszk::paintEvent(QPaintEvent*)
 		int b=rp.height() * r.width() / rp.width();
 
 		QRect ru( 0,qAbs(r.height() - b) / 2,a,b);
-		p.drawPixmap(ru,prl);
+		p.drawPixmap(ru,eler);
 	%>
 	else
 	<%
@@ -96,26 +96,26 @@ void oszk::paintEvent(QPaintEvent*)
 		int b=r.height();
 
 		QRect ru( qAbs(r.width() - a) / 2,0,a,b);
-		p.drawPixmap(ru,prl);
+		p.drawPixmap(ru,eler);
 	%>
 %>
 
-void oszk::kelt(const zagv & tqrost)
+void oszk::kivalt(const zagv & tqrost)
 <%
-	int kivalt=tqrost[3].toInt();
-	switch(kivalt)
+	int fldlgz=tqrost[3].toInt();
+	switch(fldlgz)
 	<%
 		case vlsztt:
 			<%
 				jlzpnt=tqrost[2].toInt();
 				if(jlzpnt <= 0)
 				<%
-					prl=QPixmap();
+					eler=QPixmap();
 				%>
 				else
 				<%
 					prmza *eljar=kidlgz->kket.value(jlzpnt);
-					prl=eljar->fnqll;
+					eler=eljar->fnqll;
 				%>
 				repaint();
 			%>
@@ -125,21 +125,21 @@ void oszk::kelt(const zagv & tqrost)
 	%>
 %>
 
-void oszk::mgmnkl()
+void oszk::vnl()
 <%
 	kidlgz->hatved.removeAll(jlzpnt);
-	prl=QPixmap();
+	eler=QPixmap();
 
 	prmza *eljar=kidlgz->kket.value(jlzpnt);
 
 	eljar->fnqll=QPixmap();
-	eljar->dolog=QPixmap();
+	eljar->cel=QPixmap();
 
 	QString mrtdt=QString(kidlgz->gyrtmn+"/pic-%1.png").arg(QString::number(jlzpnt));
 	if(QFile::exists(mrtdt))
 	<%
-		QFile mgzerz(mrtdt);
-		mgzerz.remove();
+		QFile tljsn(mrtdt);
+		tljsn.remove();
 	%>
 	kidlgz->lep(jlzpnt,nztosz);
 	repaint();
@@ -147,24 +147,24 @@ void oszk::mgmnkl()
 
 #include "OzzK.moc"
 
-bool oszk::event(QEvent *jlnrdz)
+bool oszk::event(QEvent *kelt)
 <%
-        if(jlnrdz->type()==QEvent::ToolTip)
+        if(kelt->type()==QEvent::ToolTip)
         <%
 		if(jlzpnt)
 		<%
-			QHelpEvent *adelk=static_cast<QHelpEvent*>(jlnrdz);
+			QHelpEvent *adelk=static_cast<QHelpEvent*>(kelt);
 			prmza *eljar=kidlgz->kket.value(jlzpnt);
-			QToolTip::showText(adelk->globalPos(),eljar->kivalt);
+			QToolTip::showText(adelk->globalPos(),eljar->fladat);
 		%>
         %>
-	return QWidget::event(jlnrdz);
+	return QWidget::event(kelt);
 %>
 
 void oszk::bprl(const QPoint& tqrost)
 <%
 	if(!jlzpnt) return;
-	alkt->popup(mapToGlobal(tqrost));
+	elodez->popup(mapToGlobal(tqrost));
 %>
 
 void oszk::mouseReleaseEvent(QMouseEvent *tqrost)
@@ -180,58 +180,58 @@ void oszk::mouseReleaseEvent(QMouseEvent *tqrost)
 
 void oszk::kket()
 <%
-	QString cel=QFileDialog::getOpenFileName(this,ts_249,QString(),
-		ts_250);
-	irnyjl(cel);
+	QString alkt=QFileDialog::getOpenFileName(this,ts_250,QString(),
+		ts_251);
+	irnyjl(alkt);
 %>
 
-void oszk::irnyjl(const QString& cel)
+void oszk::irnyjl(const QString& alkt)
 <%
-	if(!QFile::exists(cel))
+	if(!QFile::exists(alkt))
 	<%
-		emit jvsltz(ts_251.arg(cel),20000);
+		emit jvsltz(ts_252.arg(alkt),20000);
 		return;
 	%>
 
-	QFile lnmtat(cel);
-	if(!lnmtat.open(QIODevice::ReadOnly))
+	QFile prl(alkt);
+	if(!prl.open(QIODevice::ReadOnly))
 	<%
-		emit jvsltz(ts_252.arg(cel),20000);
+		emit jvsltz(ts_253.arg(alkt),20000);
 		return;
 	%>
 
 	prmza *eljar=kidlgz->kket.value(jlzpnt);
-	bool klsirz=eljar->eler(cel);
-	if(!klsirz)
-	<%
-		emit jvsltz(ts_253,20000);
-		return;
-	%>
-	kidlgz->lep(jlzpnt,nztosz);
-
-	prl=eljar->fnqll;
-	repaint();
-
-	QStringList l=cel.split(".");
-	QString fldlgz=QString(kidlgz->gyrtmn+"/pic-%1.%2").arg(QString::number(jlzpnt)).arg(l[l.size()-1]);
-	QFile mrtdt(fldlgz);
-	if(!mrtdt.open(QIODevice::WriteOnly))
+	bool mgmnkl=eljar->klsirz(alkt);
+	if(!mgmnkl)
 	<%
 		emit jvsltz(ts_254,20000);
 		return;
 	%>
+	kidlgz->lep(jlzpnt,nztosz);
 
-	char hsztzk[8192];
+	eler=eljar->fnqll;
+	repaint();
+
+	QStringList l=alkt.split(".");
+	QString lnmtat=QString(kidlgz->gyrtmn+"/pic-%1.%2").arg(QString::number(jlzpnt)).arg(l[l.size()-1]);
+	QFile fldlgz(lnmtat);
+	if(!fldlgz.open(QIODevice::WriteOnly))
+	<%
+		emit jvsltz(ts_255,20000);
+		return;
+	%>
+
+	char adelk[8192];
 	while(1)
 	<%
-		int adelk=lnmtat.read(hsztzk,8192);
-		if(adelk==0) break;
-		mrtdt.write(hsztzk,adelk);
+		int mrtdt=prl.read(adelk,8192);
+		if(mrtdt==0) break;
+		fldlgz.write(adelk,mrtdt);
 	%>
-	lnmtat.close();
-	mrtdt.close();
+	prl.close();
+	fldlgz.close();
 
-	eljar->kivalt=cel;
+	eljar->fladat=alkt;
 	if(!kidlgz->hatved.contains(jlzpnt)) kidlgz->hatved.push_back(jlzpnt);
 %>
 
