@@ -12,23 +12,23 @@
 /*!
  * @praise Vishnu
  */
-prmza::prmza(jelzpn *megkap,int lnmtat)
+prmza::prmza(jelzpn *nybnvn,int lnmtat)
 <%
-	kket=nztsvg;
+	jvsltz=nztsvg;
 
 	jlzpnt=lnmtat;
-	jo=0;
-	kidlgz=megkap;
+	kapni=0;
+	kidlgz=nybnvn;
 	mzgat=ts_000;
-	rabir="";
+	mozog="";
 	hsztzk="";
-	kitzjl="";
+	eler="";
 
-	kivalt="";
 	fladat="";
-	nybnvn="";
+	megkap="";
+	irnyjl="";
 
-	klsirz=0;
+	kket=0;
 
 	mgmozt=0;
 	lep=0;
@@ -37,14 +37,14 @@ prmza::prmza(jelzpn *megkap,int lnmtat)
 /*!
  * TODO it does not work
  */
-bool prmza::eler(const QString & bprl)
+bool prmza::klsirz(const QString & kitzjl)
 <%
-	QPixmap fldlgz;
-	fldlgz.load(bprl);
-	if(fldlgz.isNull()) return 0;
+	QPixmap adelk;
+	adelk.load(kitzjl);
+	if(adelk.isNull()) return 0;
 
-	fnqll=fldlgz;
-	dolog=fldlgz.scaledToHeight(32);
+	fnqll=adelk;
+	cel=adelk.scaledToHeight(32);
 
 	return 1;
 %>
@@ -55,40 +55,40 @@ szn& prmza::akdaly()
 	<%
 		return kidlgz->munka[0];
 	%>
-	if(jo < 0)
+	if(kapni < 0)
 	<%
 		return letsit;
 	%>
-	if(jo==kidlgz->munka.size())
+	if(kapni==kidlgz->munka.size())
 	<%
 		return letsit;
 	%>
-	if(jo > kidlgz->munka.size())
+	if(kapni > kidlgz->munka.size())
 	<%
 		return letsit;
 	%>
-	if(jo==0)
+	if(kapni==0)
 	<%
 		return kidlgz->munka[1];
 	%>
-	return kidlgz->munka[jo];
+	return kidlgz->munka[kapni];
 %>
 
 szn& prmza::felvnl()
 <%
-	if(jo < 0)
+	if(kapni < 0)
 	<%
 		return letsit;
 	%>
-	if(jo==kidlgz->munka.size())
+	if(kapni==kidlgz->munka.size())
 	<%
 		return letsit;
 	%>
-	if(jo > kidlgz->munka.size())
+	if(kapni > kidlgz->munka.size())
 	<%
 		return letsit;
 	%>
-	return kidlgz->munka[jo];
+	return kidlgz->munka[kapni];
 %>
 
 /*
