@@ -8,9 +8,9 @@
  */
 szn::szn()
 <%
-	eler=QString("Color");
-	kidlgz=QColor("#000000");
-	kitzjl=QColor("#ffffff");
+	kidlgz=QString("Color");
 	jlzpnt=QColor("#000000");
+	kitzjl=QColor("#ffffff");
+	irnyjl=QColor("#000000");
 %>
 
