@@ -21,7 +21,7 @@ class szrt: public QGraphicsEllipseItem
 		int type() const <% return gratype(19); %>
 		felu *korrkt;
 
-		rslt *akdaly;
+		rslt *cel;
 		void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget *);
 
 %>;
